<?php

namespace InSegment\WorkersFramework\Console\Commands;

use Shavshukov\EventAppBase\Console\AppCommand;

use InSegment\WorkersFramework\Interfaces\ConnectionListInterface;
use InSegment\WorkersFramework\Providers\QueueConnectionServiceProvider;
use InSegment\WorkersFramework\Services\WorkerRunner;

class Test extends AppCommand
{
    
    /**
     * {@inheritDoc}
     */
    public function usage(): string
    {
        return 'Test a worker queue';
    }

    /**
     * {@inheritDoc}
     */
    public function handle(array $arguments)
    {
        $workerName = $arguments[0] ?? null;
        echo "Testing worker {$workerName}\n";
        
        if (!$workerName) {
            echo "Please, specify the worker name";
            return $this->app->stop();
        }
        
        $this->app->registerProviders([
            new QueueConnectionServiceProvider($this->app),
        ], $this->app);
        
        return $this->app->service('queue-connections-list')->then(function (ConnectionListInterface $connections) use ($workerName) {
            return (new WorkerRunner($this->app, $connections, $workerName))->testWorker()->then(function ($testResult) {
                echo $testResult . "\n";
                return $this->app->stop();
            });
        });
    }

    /**
     * {@inheritDoc}
     */
    public function help(string $entryFileName): string
    {
        return implode("\n", [
            "Usage: {$entryFileName} test <worker name>\n",
            'Test a worker queue and get a message count'
        ]);
    }
    
}
